/// <reference types="react" />
export declare type FoundationListDataProviderSortDirection = 'asc' | 'desc';
export interface FoundationListDataProviderRowType<TRowData> {
    data: TRowData;
    id: number | string;
}
export interface FoundationListDataProviderData<TRowData> {
    items: Array<FoundationListDataProviderRowType<TRowData>>;
    totalCount: number;
}
export interface FoundationListDataProviderResultMeta {
    sortBy: string;
    sortDirection: FoundationListDataProviderSortDirection;
}
export interface FoundationListDataProviderResultInitializing {
    state: 'error-initial' | 'fetching-initial';
}
export interface FoundationListDataProviderResultInitialized<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>> {
    data: TData;
    meta: FoundationListDataProviderResultMeta;
    state: 'error-more' | 'error-sort' | 'fetching-more' | 'fetching-sort' | 'success';
}
export declare type FoundationListDataProviderResult<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>> = FoundationListDataProviderResultInitializing | FoundationListDataProviderResultInitialized<TRowData, TData>;
export declare type FoundationListDataProviderFetchMode = 'fetching-initial' | 'fetching-more' | 'fetching-sort';
export declare type FoundationListDataProviderFetchState = FoundationListDataProviderFetchMode | 'error-initial' | 'error-more' | 'error-sort' | 'success';
export interface FoundationListDataProviderFetchInitialHandler<TOptions = never> {
    (options?: TOptions): void;
}
export interface FoundationListDataProviderFetchMoreHandler<TOptions = never> {
    (limit: number, options?: TOptions): void;
}
export interface FoundationListDataProviderFetchSortHandler<TOptions = never> {
    (sortBy: string, options?: TOptions): void;
}
export interface FoundationListDataProviderFetch<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>, TOptions = never> {
    (offset: number, limit: number, sortBy: string, sortDirection: FoundationListDataProviderSortDirection, options?: TOptions): Promise<FoundationListDataProviderFetchResult<TRowData, TData>>;
}
export interface FoundationListDataProviderFetchResult<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>> {
    data: TData;
    meta: {
        orderBy: string;
        orderDirection: FoundationListDataProviderSortDirection;
    };
}
export interface FoundationListDataProviderContextType<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>, TOptions = never> {
    fetchInitial: FoundationListDataProviderFetchInitialHandler<TOptions>;
    fetchMore: FoundationListDataProviderFetchMoreHandler<TOptions>;
    fetchSort: FoundationListDataProviderFetchSortHandler<TOptions>;
    result: FoundationListDataProviderResult<TRowData, TData>;
}
export interface FoundationListDataProviderProps<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>, TOptions = never> {
    children: (context: FoundationListDataProviderContextType<TRowData, TData, TOptions>) => React.ReactElement;
    fetchData: FoundationListDataProviderFetch<TRowData, TData, TOptions>;
    initialFetchDataOptions?: TOptions;
    initialLimit?: number;
    initialSortBy?: string;
    initialSortDirection?: FoundationListDataProviderSortDirection;
}
